Improve this doc

# $parse

Here are the list of errors in the $parse namespace.

Name | Description
--- | ---
isecdom | Referencing a DOM node in Expression
isecff | Referencing 'call', 'apply' and 'bind' Disallowed
isecfld | Referencing Disallowed Field in Expression
isecfn | Referencing Function Disallowed
isecobj | Referencing Object Disallowed
isecwindow | Referencing Window object in Expression
lexerr | Lexer Error
syntax | Syntax Error
ueoe | Unexpected End of Expression